pynrc.nrc_hci
=============

.. currentmodule:: pynrc

.. autoclass:: nrc_hci
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~obs_hci.gen_offset_psf

   .. rubric:: Methods Documentation

   .. automethod:: gen_offset_psf

